==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/IPRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.IPRuleArgs.builder
import com.pulumi.azurenative.containerregistry.kotlin.enums.Action
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * IP rule with specific IP or IP range in CIDR format.
 * @property action The action of IP ACL rule.
 * @property iPAddressOrRange Specifies the IP or IP range in CIDR format. Only IPV4 address is allowed.
 */
public data class IPRuleArgs(
    public val action: Output<Either<String, Action>>? = null,
    public val iPAddressOrRange: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.IPRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.IPRuleArgs =
        com.pulumi.azurenative.containerregistry.inputs.IPRuleArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .iPAddressOrRange(iPAddressOrRange.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IPRuleArgs].
 */
@PulumiTagMarker
public class IPRuleArgsBuilder internal constructor() {
    private var action: Output<Either<String, Action>>? = null

    private var iPAddressOrRange: Output<String>? = null

    /**
     * @param value The action of IP ACL rule.
     */
    @JvmName("ujujmxmepvtplasu")
    public suspend fun action(`value`: Output<Either<String, Action>>) {
        this.action = value
    }

    /**
     * @param value Specifies the IP or IP range in CIDR format. Only IPV4 address is allowed.
     */
    @JvmName("lhinpaahvoblwyym")
    public suspend fun iPAddressOrRange(`value`: Output<String>) {
        this.iPAddressOrRange = value
    }

    /**
     * @param value The action of IP ACL rule.
     */
    @JvmName("qkkqkehlvdukgupe")
    public suspend fun action(`value`: Either<String, Action>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The action of IP ACL rule.
     */
    @JvmName("ernieuitgjfjmltg")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Action>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The action of IP ACL rule.
     */
    @JvmName("infkdbpcfhbmwusl")
    public fun action(`value`: Action) {
        val toBeMapped = Either.ofRight<String, Action>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Specifies the IP or IP range in CIDR format. Only IPV4 address is allowed.
     */
    @JvmName("xiuhjvsqujkicqgo")
    public suspend fun iPAddressOrRange(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.iPAddressOrRange = mapped
    }

    internal fun build(): IPRuleArgs = IPRuleArgs(
        action = action,
        iPAddressOrRange = iPAddressOrRange ?: throw PulumiNullFieldException("iPAddressOrRange"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/IPRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.IPRuleArgs.builder
import com.pulumi.azurenative.containerregistry.kotlin.enums.Action
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * IP rule with specific IP or IP range in CIDR format.
 * @property action The action of IP ACL rule.
 * @property iPAddressOrRange Specifies the IP or IP range in CIDR format. Only IPV4 address is allowed.
 */
public data class IPRuleArgs(
    public val action: Output<Either<String, Action>>? = null,
    public val iPAddressOrRange: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.IPRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.IPRuleArgs =
        com.pulumi.azurenative.containerregistry.inputs.IPRuleArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .iPAddressOrRange(iPAddressOrRange.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IPRuleArgs].
 */
@PulumiTagMarker
public class IPRuleArgsBuilder internal constructor() {
    private var action: Output<Either<String, Action>>? = null

    private var iPAddressOrRange: Output<String>? = null

    /**
     * @param value The action of IP ACL rule.
     */
    @JvmName("goyqhbdqgukxlwwm")
    public suspend fun action(`value`: Output<Either<String, Action>>) {
        this.action = value
    }

    /**
     * @param value Specifies the IP or IP range in CIDR format. Only IPV4 address is allowed.
     */
    @JvmName("ewwvixojcrttogkc")
    public suspend fun iPAddressOrRange(`value`: Output<String>) {
        this.iPAddressOrRange = value
    }

    /**
     * @param value The action of IP ACL rule.
     */
    @JvmName("xhbfoxyqimpmtqoc")
    public suspend fun action(`value`: Either<String, Action>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The action of IP ACL rule.
     */
    @JvmName("suorvevcckdoeviq")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Action>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The action of IP ACL rule.
     */
    @JvmName("rhxllpkxltxjntnu")
    public fun action(`value`: Action) {
        val toBeMapped = Either.ofRight<String, Action>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Specifies the IP or IP range in CIDR format. Only IPV4 address is allowed.
     */
    @JvmName("agmehqubxpdrvxhc")
    public suspend fun iPAddressOrRange(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.iPAddressOrRange = mapped
    }

    internal fun build(): IPRuleArgs = IPRuleArgs(
        action = action,
        iPAddressOrRange = iPAddressOrRange ?: throw PulumiNullFieldException("iPAddressOrRange"),
    )
}
